"""
SQLAlchemy models for message analyses.
"""

from sqlalchemy import Column, DateTime, Integer, Text
from sqlalchemy.sql import func

from app.db.base_class import Base


class Analysis(Base):
    """
    Model for storing message analysis results.
    """
    id = Column(Integer, primary_key=True, index=True)

    # Analysis details
    analysis_text = Column(Text, nullable=False)

    # Metadata
    created_at = Column(DateTime, default=func.now(), nullable=False, index=True)
    start_date = Column(DateTime, nullable=False)
    end_date = Column(DateTime, nullable=False)

    def __repr__(self) -> str:
        """
        String representation of the analysis.
        """
        return f"<Analysis {self.id}: {self.start_date} to {self.end_date} at {self.created_at}>"
