"""Initial migration

Revision ID: f97bceaaef6c
Revises:
Create Date: 2023-09-14 12:00:00.000000

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = 'f97bceaaef6c'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # Create message table
    op.create_table(
        'message',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('sender_phone', sa.String(length=20), nullable=False),
        sa.Column('sender_name', sa.String(length=255), nullable=False),
        sa.Column('message_body', sa.Text(), nullable=False),
        sa.Column('timestamp', sa.DateTime(), nullable=False),
        sa.Column('analyzed', sa.Boolean(), nullable=True, default=False),
        sa.Column('last_analyzed_at', sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint('id'),
    )
    op.create_index(op.f('ix_message_id'), 'message', ['id'], unique=False)
    op.create_index(op.f('ix_message_sender_phone'), 'message', ['sender_phone'], unique=False)
    op.create_index(op.f('ix_message_sender_name'), 'message', ['sender_name'], unique=False)
    op.create_index(op.f('ix_message_timestamp'), 'message', ['timestamp'], unique=False)
    op.create_index(op.f('ix_message_analyzed'), 'message', ['analyzed'], unique=False)

    # Create analysis table
    op.create_table(
        'analysis',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('analysis_text', sa.Text(), nullable=False),
        sa.Column('created_at', sa.DateTime(), nullable=False),
        sa.Column('start_date', sa.DateTime(), nullable=False),
        sa.Column('end_date', sa.DateTime(), nullable=False),
        sa.PrimaryKeyConstraint('id'),
    )
    op.create_index(op.f('ix_analysis_id'), 'analysis', ['id'], unique=False)
    op.create_index(op.f('ix_analysis_created_at'), 'analysis', ['created_at'], unique=False)


def downgrade():
    op.drop_index(op.f('ix_analysis_created_at'), table_name='analysis')
    op.drop_index(op.f('ix_analysis_id'), table_name='analysis')
    op.drop_table('analysis')

    op.drop_index(op.f('ix_message_analyzed'), table_name='message')
    op.drop_index(op.f('ix_message_timestamp'), table_name='message')
    op.drop_index(op.f('ix_message_sender_name'), table_name='message')
    op.drop_index(op.f('ix_message_sender_phone'), table_name='message')
    op.drop_index(op.f('ix_message_id'), table_name='message')
    op.drop_table('message')
